==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ta/mail.php <==
<?php

return array(
    'a_user_canceled' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படி கோரிக்கையை ரத்து செய்துள்ளார்',
    'a_user_requested' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படியைக் கோரியுள்ளார்',
    'accessory_name' => 'துணை பெயர்:',
    'additional_notes' => 'கூடுதல் குறிப்புகள்:',
    'admin_has_created' => 'ஒரு வலைத்தளம் உங்களுக்கு ஒரு கணக்கை உருவாக்கியுள்ளது: இணையத்தளம்.',
    'asset' => 'சொத்து:',
    'asset_name' => 'சொத்து பெயர்:',
    'asset_requested' => 'சொத்து கோரப்பட்டது',
    'asset_tag' => 'சொத்து குறிச்சொல்:',
    'assigned_to' => 'ஒதுக்கப்படும்',
    'best_regards' => 'சிறந்த வாழ்த்துக்கள்,',
    'canceled' => 'ரத்து செய்தவர்:',
    'checkin_date' => 'சரி தேதி',
    'checkout_date' => 'புதுப்பிப்பு தேதி:',
    'click_to_confirm' => 'உங்கள்: இணைய கணக்கை உறுதிப்படுத்த பின்வரும் இணைப்பை கிளிக் செய்யவும்:',
    'click_on_the_link_accessory' => 'நீங்கள் இணைப்பு பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_on_the_link_asset' => 'நீங்கள் சொத்தை பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'தற்போதைய QTY',
    'Days' => 'நாட்களில்',
    'days' => 'நாட்களில்',
    'expecting_checkin_date' => 'எதிர்பார்த்த செக்கின் தேதி:',
    'expires' => 'காலாவதியாகிறது',
    'Expiring_Assets_Report' => 'சொத்துக்கள் அறிக்கை முடிவடைகிறது.',
    'Expiring_Licenses_Report' => 'காலாவதி உரிமைகள் அறிக்கை.',
    'hello' => 'வணக்கம்',
    'hi' => 'வணக்கம்',
    'i_have_read' => 'நான் பயன்பாட்டு விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறேன், இந்த உருப்படியைப் பெற்றுள்ளேன்.',
    'item' => 'பொருள்:',
    'Item_Request_Canceled' => 'பொருள் கோரிக்கை ரத்து செய்யப்பட்டது',
    'Item_Requested' => 'பொருள் கோரியது',
    'link_to_update_password' => 'தயவுசெய்து புதுப்பிக்க பின்வரும் இணைப்பை கிளிக் செய்யவும்: உங்கள் இணைய கடவுச்சொல்:',
    'login_first_admin' => 'கீழே உள்ள சான்றுகளை பயன்படுத்தி உங்கள் புதிய Snipe-IT நிறுவலுக்கு உள்நுழையவும்:',
    'login' => 'உள் நுழை:',
    'Low_Inventory_Report' => 'குறைவான சரக்கு அறிக்கை',
    'min_QTY' => 'குறைந்தது QTY',
    'name' => 'பெயர்',
    'new_item_checked' => 'உங்கள் பெயரில் ஒரு புதிய உருப்படி சோதிக்கப்பட்டது, விவரங்கள் கீழே உள்ளன.',
    'password' => 'கடவுச்சொல்:',
    'password_reset' => 'கடவுச்சொல்லை மீட்டமை',

    'read_the_terms' => 'கீழே உள்ள விதிமுறைகளை தயவுசெய்து படித்துப் பாருங்கள்.',
    'read_the_terms_and_click' => 'கீழே உள்ள விதிமுறைகளைப் படியுங்கள், மற்றும் நீங்கள் பயன்படுத்தும் விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்து, சொத்துடைமையைப் பெற்றுள்ளீர்கள்.',
    'requested' => 'கோரியவர்:',
    'reset_link' => 'உங்கள் கடவுச்சொல்லை மீட்டமை இணைப்பு',
    'reset_password' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க இங்கே கிளிக் செய்க:',
    'serial' => 'Serial',
    'supplier' => 'சப்ளையர்',
    'tag' => 'டேக்',
    'test_email' => 'ஸ்னாப்-டி இருந்து மின்னஞ்சல் சோதனை',
    'test_mail_text' => 'இது Snipe-IT சொத்து முகாமைத்துவ கணினியிலிருந்து ஒரு சோதனை ஆகும். இதை நீங்கள் பெற்றிருந்தால், மின்னஞ்சல் வேலை செய்கிறது :)',
    'the_following_item' => 'பின்வரும் உருப்படி பின்வருமாறு சரிபார்க்கப்பட்டது:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க, இந்த படிவத்தை பூர்த்தி செய்க:',
    'type' => 'வகை',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'வரவேற்பு: பெயர்',
    'welcome_to' => 'வரவேற்கிறோம்: வலை!',
    'your_credentials' => 'உங்கள் கத்தரி-ஐடி சான்றுகள்',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ta/mail.php <==
<?php

return [
    'a_user_canceled' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படி கோரிக்கையை ரத்து செய்துள்ளார்',
    'a_user_requested' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படியைக் கோரியுள்ளார்',
    'accessory_name' => 'துணை பெயர்:',
    'additional_notes' => 'கூடுதல் குறிப்புகள்:',
    'admin_has_created' => 'ஒரு வலைத்தளம் உங்களுக்கு ஒரு கணக்கை உருவாக்கியுள்ளது: இணையத்தளம்.',
    'asset' => 'சொத்து:',
    'asset_name' => 'சொத்து பெயர்:',
    'asset_requested' => 'சொத்து கோரப்பட்டது',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'ஒதுக்கப்படும்',
    'best_regards' => 'சிறந்த வாழ்த்துக்கள்,',
    'canceled' => 'ரத்து செய்தவர்:',
    'checkin_date' => 'சரி தேதி',
    'checkout_date' => 'புதுப்பிப்பு தேதி:',
    'click_to_confirm' => 'உங்கள்: இணைய கணக்கை உறுதிப்படுத்த பின்வரும் இணைப்பை கிளிக் செய்யவும்:',
    'click_on_the_link_accessory' => 'நீங்கள் இணைப்பு பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_on_the_link_asset' => 'நீங்கள் சொத்தை பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'தற்போதைய QTY',
    'Days' => 'நாட்களில்',
    'days' => 'நாட்களில்',
    'expecting_checkin_date' => 'எதிர்பார்த்த செக்கின் தேதி:',
    'expires' => 'காலாவதியாகிறது',
    'Expiring_Assets_Report' => 'சொத்துக்கள் அறிக்கை முடிவடைகிறது.',
    'Expiring_Licenses_Report' => 'காலாவதி உரிமைகள் அறிக்கை.',
    'hello' => 'வணக்கம்',
    'hi' => 'வணக்கம்',
    'i_have_read' => 'நான் பயன்பாட்டு விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறேன், இந்த உருப்படியைப் பெற்றுள்ளேன்.',
    'item' => 'பொருள்:',
    'Item_Request_Canceled' => 'பொருள் கோரிக்கை ரத்து செய்யப்பட்டது',
    'Item_Requested' => 'பொருள் கோரியது',
    'link_to_update_password' => 'தயவுசெய்து புதுப்பிக்க பின்வரும் இணைப்பை கிளிக் செய்யவும்: உங்கள் இணைய கடவுச்சொல்:',
    'login_first_admin' => 'கீழே உள்ள சான்றுகளை பயன்படுத்தி உங்கள் புதிய Snipe-IT நிறுவலுக்கு உள்நுழையவும்:',
    'login' => 'உள் நுழை:',
    'Low_Inventory_Report' => 'குறைவான சரக்கு அறிக்கை',
    'min_QTY' => 'குறைந்தது QTY',
    'name' => 'பெயர்',
    'new_item_checked' => 'உங்கள் பெயரில் ஒரு புதிய உருப்படி சோதிக்கப்பட்டது, விவரங்கள் கீழே உள்ளன.',
    'password' => 'கடவுச்சொல்:',
    'password_reset' => 'கடவுச்சொல்லை மீட்டமை',

    'read_the_terms' => 'கீழே உள்ள விதிமுறைகளை தயவுசெய்து படித்துப் பாருங்கள்.',
    'read_the_terms_and_click' => 'கீழே உள்ள விதிமுறைகளைப் படியுங்கள், மற்றும் நீங்கள் பயன்படுத்தும் விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்து, சொத்துடைமையைப் பெற்றுள்ளீர்கள்.',
    'requested' => 'கோரியவர்:',
    'reset_link' => 'உங்கள் கடவுச்சொல்லை மீட்டமை இணைப்பு',
    'reset_password' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க இங்கே கிளிக் செய்க:',
    'serial' => 'Serial',
    'supplier' => 'சப்ளையர்',
    'tag' => 'டேக்',
    'test_email' => 'ஸ்னாப்-டி இருந்து மின்னஞ்சல் சோதனை',
    'test_mail_text' => 'இது Snipe-IT சொத்து முகாமைத்துவ கணினியிலிருந்து ஒரு சோதனை ஆகும். இதை நீங்கள் பெற்றிருந்தால், மின்னஞ்சல் வேலை செய்கிறது :)',
    'the_following_item' => 'பின்வரும் உருப்படி பின்வருமாறு சரிபார்க்கப்பட்டது:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க, இந்த படிவத்தை பூர்த்தி செய்க:',
    'type' => 'வகை',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'வரவேற்பு: பெயர்',
    'welcome_to' => 'வரவேற்கிறோம்: வலை!',
    'your_credentials' => 'உங்கள் கத்தரி-ஐடி சான்றுகள்',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
